Welcome to Pyke

# Welcome to Pyke ## Release 1.1 Pyke introduces a form of Logic Programming (inspired by Prolog) to the Python community by providing a knowledge-based inference engine (expert system) written in 100% Python. Unlike Prolog, Pyke integrates with Python allowing you to invoke Pyke from Python and intermingle Python statements and expressions within your expert system rules. Pyke was developed to significantly raise the bar on code reuse. Here's how it works: You write a set of Python functions, and a set of Pyke rules to direct the configuration and combination of these functions. These functions refer to Pyke pattern variables within the function body. Pyke may instantiate each of your functions multiple times, providing a different set of constant values for each of the pattern variables used within the function body. Each of these instances appears as a different function. Pyke then automatically assembles these customized functions into a complete program (function call graph) to meet a specific need or use case. Pyke calls this function call graph a plan. In this way, Pyke provides a way to radically customize and adapt your Python code for a specific purpose or use case. Doing this essentially makes Pyke a very high-level compiler. And taking this approach also produces dramatic increases in performance. And Pyke is very successful at this, providing order of magnitude improvements in: Code adaptability (or customization), Code reuse and Performance Pyke does not replace Python, nor is meant to compete with Python. Python is an excellent general purpose programming language, that allows you to "program in the small". Pyke builds upon Python by also giving you tools to directly program in the large. Oh, and Pyke uses Logic Programming to do all of this. So if you're interested in Logic Programming or Expert Systems, well Pyke has that too... ## Pyke on Google Groups Please join Pyke on Google Groups for questions and discussion! ## FAQ There is also an FAQ list on the sourceforge wiki, to make it easy to contribute.
Copyright © 2007-2009 Bruce Frederiksen

Page last modified Thu, Mar 04 2010.